package com.example.nto.service.impl;

import com.example.nto.entity.Code;
import com.example.nto.entity.Employee;
import com.example.nto.repository.CodeRepository;
import com.example.nto.repository.EmployeeRepository;
import com.example.nto.service.EmployeeService;
import com.example.nto.service.exception.CodeNotFoundException;
import com.example.nto.service.exception.EmployeeNotFoundException;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;

@Service
@RequiredArgsConstructor
public class EmployeeServiceImpl implements EmployeeService {

    private final EmployeeRepository employeeRepository;

    private final CodeRepository codeRepository;

    @Override
    public void employeeExists(final String login) {
        if (!employeeRepository.existsByLogin(login)) {
            throw new EmployeeNotFoundException();
        }
    }

    @Override
    public Employee getEmployee(final String login) {
        if (!employeeRepository.existsByLogin(login)) {
            throw new EmployeeNotFoundException();
        }
        return employeeRepository.findEmployeeByLogin(login);
    }

    @Override
    public void updateVisit(final String login, final long value) {
        if (!employeeRepository.existsByLogin(login)) {
            throw new EmployeeNotFoundException();
        }
        if (!codeRepository.existsByValue(value)) {
            throw new CodeNotFoundException();
        }
        final Employee employee = employeeRepository.findEmployeeByLogin(login);
        employee.setLastVisit(LocalDateTime.now());
        employeeRepository.save(employee);
    }
}
